<?php

/**
 * Classe plxUtils rassemblant les fonctions utiles à PluXml
 *
 * @package SPX
 * @author	Evrard-je
 **/
class spxnewsletterUtils {

	
	/**
	 * Méthode qui converti les liens relatifs en liens absolus
	 *
	 * @param	base		url du site qui sera rajoutée devant les liens relatifs
	 * @param	html		chaine de caractères à convertir
	 * @param	dirs		configuration des dossiers issues du fichier parametres.xml
	 * @return	string		chaine de caractères modifiée
	 * @author	Stephane F., Amaury Graillat
	 **/
	public static function rel2abs($base, $html) {

		// url des plugins
		$html = preg_replace('@\<([^>]*) (href|src)=(["\'])[\.]/plugins@i', '<$1 $2=$3'.$base.'plugins', $html);
		// generate server-only replacement for root-relative URLs
		$server = preg_replace('@^([^:]+)://([^/]+)(/|$).*@', '\1://\2/', $base);
		// on repare les liens ne commençant que part #
		$get = plxUtils::getGets();
		$html = preg_replace('@\<([^>]*) (href|src)="#@i', '<\1 \2="' . $get . '#', $html);
		// replace root-relative URLs
		$html = preg_replace('@\<([^>]*) (href|src)=".?/@i', '<\1 \2="' . $server, $html);
		// replace base-relative URLs
		$html = preg_replace('@\<([^>]*) (href|src)="([^:"]*|[^:"]*:[^/"][^"]*)"@i', '<\1 \2="' . $base . '\3"', $html);
		// unreplace fully qualified URLs with proto: that were wrongly added $base
		$html = preg_replace('@\<([^>]*) (href|src)="'. $base . '([^:"]+):@i', '<\1 \2="\3:', $html);
		return $html;

	}

	
	public static function dirToArray($dir) { 
	   
	   $result = array(); 
	
	   $cdir = scandir($dir); 
	   foreach ($cdir as $key => $value) 
	   { 
		  if (!in_array($value,array(".",".."))) 
		  { 
			 if (is_dir($dir . DIRECTORY_SEPARATOR . $value)) 
			 { 
				$result[$value] = self::dirToArray($dir . DIRECTORY_SEPARATOR . $value); 
			 } 
			 else 
			 { 
				$result[] = $value; 
			 } 
		  } 
	   } 
	   
	   return $result; 
	} 

	/**
     * Get an array that represents directory tree
     * @param string $directory     Directory path
     * @param bool $recursive         Include sub directories
     * @param bool $listDirs         Include directories on listing
     * @param bool $listFiles         Include files on listing
     * @param regex $exclude         Exclude paths that matches this regex
     */
   public static function directoryToArray($directory, $ds="/", $recursive = true, $listDirs = false, $listFiles = true, $exclude = '') { 
       // $directory_separator=DIRECTORY_SEPARATOR;
		$directory_separator=$ds;
		$arrayItems = array();
        $skipByExclude = false;
        $handle = opendir($directory);
        if ($handle) {
            while (false !== ($file = readdir($handle))) {
            preg_match("/(^(([\.]){1,2})$|(\.(svn|git|md))|(Thumbs\.db|\.DS_STORE))$/iu", $file, $skip);
            if($exclude){
                preg_match($exclude, $file, $skipByExclude);
            }
            if (!$skip && !$skipByExclude) {
                if (is_dir($directory. $directory_separator . $file)) {
                    if($recursive) {
                        $arrayItems = array_merge($arrayItems, self::directoryToArray($directory. $directory_separator . $file, $ds, $recursive, $listDirs, $listFiles, $exclude));
                    }
                    if($listDirs){
                        $file = $directory . $directory_separator . $file;
                        $arrayItems[] = $file;
                    }
                } else {
                    if($listFiles){
                        $file = $directory . $directory_separator . $file;
                        $arrayItems[] = $file;
                    }
                }
            }
        }
        closedir($handle);
        }
        return $arrayItems;
    }

	public static function send_mails($from,$subjet,$texte,$emails,$reply="") {
		if ($reply=="") $reply=$from;
		$headers = "From: ".$from."\n".
		"Return-Path: ".$reply."\n".
		"MIME-Version: 1.0\n".
		"Content-Type: text/plain; charset=iso-8859-1\n".
		"Content-Transfer-Encoding: 8bit\n";
		//foreach($emails as $email) mail($email, utf8_decode($subjet), utf8_decode($texte), $headers);
		foreach($emails as $email) {
			mail($email, utf8_decode($subjet), utf8_decode($texte), $headers);
		}

	}
	
	public static function send_mailsHtml($from,$subjet,$texte,$emails,$reply="") {
		if ($reply=="") $reply=$from;
		$headers = 'From: '.$from. "\n";
		$headers .="Return-Path: ".$reply."\n";
		$headers .= 'MIME-Version: 1.0'. "\n";
		$headers .= 'Content-type: text/html; charset="'.PLX_CHARSET.'"'."rn";
		$headers .='Content-Transfer-Encoding: 8bit'; // ici on précise qu'il y a des caractères accentués
		//foreach($emails as $email) mail($email, utf8_decode($subjet), utf8_decode($texte), $headers);
		foreach($emails as $email) {
			//echo ("email to ".$email." sujet=".$subjet."\n<br>");
			mail($email, $subjet, $texte, $headers);
		}

	}
	
	
	# print select
	public static function printSelect($name, $array, $selected='', $readonly=false, $class='', $id=true) {
		$s='';
		if(!is_array($array)) $array=array();

		$id = ($id?' id="id_'.$name.'"':'');
		if($readonly)
			$s.= '<input type="hidden" name="'.$name.'" value="'.$selected.'" /><select'.$id.' name="'.$name.'" disabled="disabled" class="readonly">'."\n";
		else
			$s.= '<select'.$id.' name="'.$name.'"'.($class!=''?' class="'.$class.'"':'').'>'."\n";
		foreach($array as $a => $b) {
			if(is_array($b)) {
				$s.= '<optgroup label="'.$a.'">'."\n";
				foreach($b as $c=>$d) {
					//if ($c=="none") $c="";
					if($c == $selected)
						$s.= "\t".'<option value="'.$c.'" selected="selected">'.$d.'</option>'."\n";
					else
						$s.= "\t".'<option value="'.$c.'">'.$d.'</option>'."\n";
				}
				$s.= '</optgroup>'."\n";
			} else {
				//if ($a=="none") $a="";
				if($a == $selected)
					$s.= "\t".'<option value="'.$a.'" selected="selected">'.$b.'</option>'."\n";
				else
					$s.= "\t".'<option value="'.$a.'">'.$b.'</option>'."\n";
			}
		}
		$s.= '</select>'."\n";
		return $s;
	}
	
	# print input
	public static function printInput($name, $value='', $type='text', $size='30-100', $readonly=false, $class='') {
		$size = explode('-',$size);
		if($readonly)
			$s= '<input id="id_'.$name.'" name="'.$name.'" type="'.$type.'" class="readonly" value="'.$value.'" size="'.$size[0].'" maxlength="'.$size[1].'" readonly="readonly" />'."\n";
		else
			$s= '<input id="id_'.$name.'" name="'.$name.'" type="'.$type.'"'.($class!=''?' class="'.$class.'"':'').' value="'.$value.'" size="'.$size[0].'" maxlength="'.$size[1].'" />'."\n";
		
		return $s;
	}
	
	# print input with id
	public static function printInput2($id_name,$name, $value='', $type='text', $size='30-100', $readonly=false, $class='') {
		$size = explode('-',$size);
		if($readonly)
			$s= '<input id="'.$id_name.'" name="'.$name.'" type="'.$type.'" class="readonly" value="'.$value.'" size="'.$size[0].'" maxlength="'.$size[1].'" readonly="readonly" />'."\n";
		else
			$s= '<input id="'.$id_name.'" name="'.$name.'" type="'.$type.'"'.($class!=''?' class="'.$class.'"':'').' value="'.$value.'" size="'.$size[0].'" maxlength="'.$size[1].'" />'."\n";
		return $s;
	}
	
	# print area
	public static function printArea($name, $value='', $cols='', $rows='', $readonly=false, $class='') {
		if($readonly)
			$s= '<textarea id="id_'.$name.'" name="'.$name.'" class="readonly" cols="'.$cols.'" rows="'.$rows.'" readonly="readonly">'.$value.'</textarea>'."\n";
		else
			$s= '<textarea id="id_'.$name.'" name="'.$name.'"'.($class!=''?' class="'.$class.'"':'').' cols="'.$cols.'" rows="'.$rows.'">'.$value.'</textarea>'."\n";
			
		return $s;
	}
	
	//-------------------------FOLDER-----------------------------//
	public static function check_file_exist($filename){
		if (file_exists($filename)) {
    		return true;
		} else {
    		return false;
		}
	}
	# new dir
	public static function newDir($newdir) {
		if(!is_dir($newdir)) { # Si le dossier n'existe pas on le créer
			if(!mkdir($newdir,0755,true))
				return false;
			else
				return true;
		} else {
			return false;
		}
	
    }
	# copy dir
	public static function copyDir($source,$destination) {
		if(!copy($source,$destination))
			return false;
		else
			return true;
    }
	
	public static function deleteFile($file) {
		if (!@unlink($file)) {
    		return false;
		}else{
			return true;
		}
	}
	public static function copyFile($file,$newfile) {
		if (!@copy($file, $newfile)) {
    		return false;
		}else{
			return true;
		}
	}
	public static function createFile($file,$content) {
		$f = fopen($file, "w");
        if($f==false)
            die("unable to create file");
		fwrite($f,$content);
        fclose ($f);
		return $file;
	}
	
	# merge multifile in one file
	// Array of css files
	/* $file = array(
		'file1.php',
		'file2.php',
		'file3.php',
		'file4.php'
	);
	
	merge_file( $file,"output.php");	
	*/
	public static function merge_file( $a ,$myFile) {
		$fo = fopen($myFile, 'w') or die("can't open file");
		foreach ($a as $file) {
   			if (file_exists($file)) {
				$file_content = file_get_contents($file);
				fwrite($fo, $file_content);
			}
		}
		fclose($fo);
	}

	
	
	/*
	
	
	public static function deleteFolder($directory){
		$directory = escapeshellarg($directory);
		exec("rm -rf $directory");
	}
	public static function createFolder($path) {
		if (!@mkdir($path, 0777, true)) {
			//ucmsUtils::tracer("can't create folder: ".$path);
    		return $path;
		}else{
			return $path;
		}
	}
	public static function copyFolder( $source, $destination ) {
		$s = "cp ".$source." ".$destination." -R";
		exec($s);
	}
	


*/





/*
	function arrayRemoveDuplicate($array, $field) {
		foreach ($array as $element)
			$cmp[] = $element[$field];
		$unique = array_unique($cmp);
		foreach ($unique as $k => $v)
			$new[] = $array[$k];
		return $new;
	}
*/
}
?>